@@ -102,7 +102,7 @@ fi
 "$LIBTOOLIZE" --force --copy --automake
 "$ACLOCAL" -I build/m4/stubs -I build/m4 ${ACLOCAL_FLAGS:-}
 "$AUTOCONF"
-# "$AUTOHEADER"
+"$AUTOHEADER"
 "$AUTOMAKE" \
     --gnu --add-missing --force --copy \
     -Wno-portability -Wno-portability
