@@ -2,7 +2,7 @@
 
 set -ef
 
-"${top_builddir}/src/aircrack-ng${EXEEXT}" \
+"${abs_builddir}/../aircrack-ng${EXEEXT}" \
     ${AIRCRACK_NG_ARGS} \
     -w "${abs_srcdir}/password.lst" \
     -a 2 \
@@ -18,7 +18,7 @@ set -ef
 	"${abs_srcdir}/Chinese-SSID-Name.pcap" \
 	"${abs_srcdir}/wpaclean_crash.pcap" \
 	"${abs_srcdir}/wps2.0.pcap" | \
-        grep 'KEY FOUND! \[ biscotte \]'
+        ${GREP} 'KEY FOUND! \[ biscotte \]'
 
 exit 0
 
