@@ -2,13 +2,13 @@
 
 set -ef
 
-echo "staytogether" | "${top_builddir}/src/aircrack-ng${EXEEXT}" \
+echo "staytogether" | "${abs_builddir}/../aircrack-ng${EXEEXT}" \
     ${AIRCRACK_NG_ARGS} \
     -e "Stay Alfred" \
     -w - \
     "${abs_srcdir}/StayAlfred.hccapx" \
     -l /dev/null | \
-        grep "KEY FOUND"
+        ${GREP} "KEY FOUND"
 
 exit 0
 
